#[non_exhaustive]pub enum NatsError {
Connect(Box<dyn StdError + Send + Sync>),
Publish(Box<dyn StdError + Send + Sync>),
Subscribe(Box<dyn StdError + Send + Sync>),
JetStream(Box<dyn StdError + Send + Sync>),
RequestTimeout,
InvalidOptions(String),
}Expand description
Errors surfaced by the NATS broker implementation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Connect(Box<dyn StdError + Send + Sync>)
Failed to establish or use the underlying async-nats connection.
Publish(Box<dyn StdError + Send + Sync>)
Failed to publish a message to the broker.
Subscribe(Box<dyn StdError + Send + Sync>)
Failed to subscribe to the requested subject.
JetStream(Box<dyn StdError + Send + Sync>)
JetStream-specific operation failed (consumer creation, ack, etc.).
RequestTimeout
A request / reply operation timed out before a reply was received.
InvalidOptions(String)
The supplied crate::SubscribeOptions combine fields in a way the broker cannot honour
(for example durable(_) without jetstream(_), or queue_group(_) together with
jetstream(_)).